
From: Michael Ellerman <michael@ellerman.id.au>

Not sure if we really need this, but it was handy to know which iSeries loop I
was testing.

Be consistent about printing which idle loop we're using, with this patch we
cover all cases.

Signed-off-by: Michael Ellerman <michael@ellerman.id.au>
Signed-off-by: Anton Blanchard <anton@samba.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc64/kernel/iSeries_setup.c |    7 +++++--
 arch/ppc64/kernel/setup.c         |    4 +++-
 2 files changed, 8 insertions(+), 3 deletions(-)

diff -puN arch/ppc64/kernel/iSeries_setup.c~ppc64-be-consistent-about-printing-which-idle-loop-were-using arch/ppc64/kernel/iSeries_setup.c
--- 25/arch/ppc64/kernel/iSeries_setup.c~ppc64-be-consistent-about-printing-which-idle-loop-were-using	Wed Jul  6 14:10:24 2005
+++ 25-akpm/arch/ppc64/kernel/iSeries_setup.c	Wed Jul  6 14:10:24 2005
@@ -946,9 +946,12 @@ void __init iSeries_early_setup(void)
 	ppc_md.calibrate_decr = iSeries_calibrate_decr;
 	ppc_md.progress = iSeries_progress;
 
-	if (get_paca()->lppaca.shared_proc)
+	if (get_paca()->lppaca.shared_proc) {
 		ppc_md.idle_loop = iseries_shared_idle;
-	else
+		printk(KERN_INFO "Using shared processor idle loop\n");
+	} else {
 		ppc_md.idle_loop = iseries_dedicated_idle;
+		printk(KERN_INFO "Using dedicated idle loop\n");
+	}
 }
 
diff -puN arch/ppc64/kernel/setup.c~ppc64-be-consistent-about-printing-which-idle-loop-were-using arch/ppc64/kernel/setup.c
--- 25/arch/ppc64/kernel/setup.c~ppc64-be-consistent-about-printing-which-idle-loop-were-using	Wed Jul  6 14:10:24 2005
+++ 25-akpm/arch/ppc64/kernel/setup.c	Wed Jul  6 14:10:24 2005
@@ -1081,8 +1081,10 @@ void __init setup_arch(char **cmdline_p)
 	ppc_md.setup_arch();
 
 	/* Use the default idle loop if the platform hasn't provided one. */
-	if (NULL == ppc_md.idle_loop)
+	if (NULL == ppc_md.idle_loop) {
 		ppc_md.idle_loop = default_idle;
+		printk(KERN_INFO "Using default idle loop\n");
+	}
 
 	paging_init();
 	ppc64_boot_msg(0x15, "Setup Done");
_
